[MPlayer-cvslog] r29251 - in trunk: AUTHORS DOCS/man/en/mplayer.1 DOCS/tech/MAINTAINERS Makefile configure libao2/ao_coreaudio.c libao2/ao_macosx.c libao2/audio_out.c

diego subversion at mplayerhq.hu
Mon May 4 16:53:47 CEST 2009


Author: diego
Date: Mon May  4 16:53:47 2009
New Revision: 29251

Log:
Rename macosx audio output driver to coreaudio.

Added:
   trunk/libao2/ao_coreaudio.c
      - copied, changed from r29245, trunk/libao2/ao_macosx.c
Deleted:
   trunk/libao2/ao_macosx.c
Modified:
   trunk/AUTHORS
   trunk/DOCS/tech/MAINTAINERS
   trunk/Makefile
   trunk/configure
   trunk/libao2/audio_out.c

Changes in other areas also in this revision:
Modified:
   trunk/DOCS/man/en/mplayer.1

Modified: trunk/AUTHORS
==============================================================================
--- trunk/AUTHORS	Mon May  4 16:49:42 2009	(r29250)
+++ trunk/AUTHORS	Mon May  4 16:53:47 2009	(r29251)
@@ -168,7 +168,7 @@ Bunkus, Moritz (Mosu) <moritz at bunkus.org
 
 Christiansen, Dan Villiom Podlaski (danchr) <danchr at daimi.au.dk>
     * timer-darwin.c
-    * ao_macosx
+    * CoreAudio audio output driver for Mac OS X
     * build system cleanups for Darwin
 
 Clagg, Jeff (snacky) <snacky at ikaruga.co.uk>

Modified: trunk/DOCS/tech/MAINTAINERS
==============================================================================
--- trunk/DOCS/tech/MAINTAINERS	Mon May  4 16:49:42 2009	(r29250)
+++ trunk/DOCS/tech/MAINTAINERS	Mon May  4 16:53:47 2009	(r29251)
@@ -204,12 +204,12 @@ libao2 drivers:
     * ao_alsa5.c - None
     * ao_alsa.c - Clemens Ladisch
     * ao_arts.c - None
+    * ao_coreaudio.c - None
     * ao_dsound.c - None
     * ao_dxr2.c - None
     * ao_esd.c - None
     * ao_ivtv.c - Benjamin Zores
     * ao_jack.c - Reimar Döffinger
-    * ao_macosx.c - None
     * ao_mpegpes.c - None
     * ao_nas.c - Tobias Diedrich
     * ao_null.c - None

Modified: trunk/Makefile
==============================================================================
--- trunk/Makefile	Mon May  4 16:49:42 2009	(r29250)
+++ trunk/Makefile	Mon May  4 16:53:47 2009	(r29251)
@@ -531,7 +531,7 @@ SRCS_MPLAYER-$(APPLE_REMOTE) += input/ar
 SRCS_MPLAYER-$(ARTS)         += libao2/ao_arts.c
 SRCS_MPLAYER-$(BL)           += libvo/vo_bl.c
 SRCS_MPLAYER-$(CACA)         += libvo/vo_caca.c
-SRCS_MPLAYER-$(COREAUDIO)    += libao2/ao_macosx.c
+SRCS_MPLAYER-$(COREAUDIO)    += libao2/ao_coreaudio.c
 SRCS_MPLAYER-$(COREVIDEO)    += libvo/vo_macosx.m
 SRCS_MPLAYER-$(DART)         += libao2/ao_dart.c
 SRCS_MPLAYER-$(DFBMGA)       += libvo/vo_dfbmga.c

Modified: trunk/configure
==============================================================================
--- trunk/configure	Mon May  4 16:49:42 2009	(r29250)
+++ trunk/configure	Mon May  4 16:53:47 2009	(r29251)
@@ -3815,10 +3815,10 @@ fi
 if test "$_coreaudio" = yes ; then
   extra_ldflags="$extra_ldflags -framework CoreAudio -framework AudioUnit -framework AudioToolbox"
   def_coreaudio='#define CONFIG_COREAUDIO 1'
-  _aomodules="macosx $_aomodules"
+  _aomodules="coreaudio $_aomodules"
 else
   def_coreaudio='#undef CONFIG_COREAUDIO'
-  _noaomodules="macosx $_noaomodules"
+  _noaomodules="coreaudio $_noaomodules"
 fi
 echores $_coreaudio
 

Copied and modified: trunk/libao2/ao_coreaudio.c (from r29245, trunk/libao2/ao_macosx.c)
==============================================================================
--- trunk/libao2/audio_out.c	Mon May  4 16:49:42 2009	(r29250)
+++ trunk/libao2/audio_out.c	Mon May  4 16:53:47 2009	(r29251)
@@ -32,7 +32,7 @@ ao_data_t ao_data={0,0,0,0,OUTBURST,-1,0
 char *ao_subdevice = NULL;
 
 extern const ao_functions_t audio_out_oss;
-extern const ao_functions_t audio_out_macosx;
+extern const ao_functions_t audio_out_coreaudio;
 extern const ao_functions_t audio_out_arts;
 extern const ao_functions_t audio_out_esd;
 extern const ao_functions_t audio_out_pulse;
@@ -68,7 +68,7 @@ const ao_functions_t* const audio_out_dr
         &audio_out_dart,
 #endif
 #ifdef CONFIG_COREAUDIO
-        &audio_out_macosx,
+        &audio_out_coreaudio,
 #endif
 #ifdef CONFIG_OSS_AUDIO
         &audio_out_oss,


More information about the MPlayer-cvslog mailing list
--- trunk/libao2/ao_macosx.c	Sun May  3 23:52:41 2009	(r29245, copy source)
+++ trunk/libao2/ao_coreaudio.c	Mon May  4 16:53:47 2009	(r29251)
@@ -1,5 +1,5 @@
 /*
  * Mac OS X audio output driver
  *
  * original copyright (C) Timothy J. Wood - Aug 2000
  * ported to MPlayer libao2 by Dan Christiansen
@@ -57,17 +57,17 @@
 static const ao_info_t info =
   {
     "Darwin/Mac OS X native audio output",
-    "macosx",
+    "coreaudio",
     "Timothy J. Wood & Dan Christiansen & Chris Roccati",
     ""
   };
 
-LIBAO_EXTERN(macosx)
+LIBAO_EXTERN(coreaudio)
 
 /* Prefix for all mp_msg() calls */
-#define ao_msg(a, b, c...) mp_msg(a, b, "AO: [macosx] " c)
+#define ao_msg(a, b, c...) mp_msg(a, b, "AO: [coreaudio] " c)
 
-typedef struct ao_macosx_s
+typedef struct ao_coreaudio_s
 {
   AudioDeviceID i_selected_dev;             /* Keeps DeviceID of the selected device. */
   int b_supports_digital;                   /* Does the currently selected device support digital mode? */
@@ -96,9 +96,9 @@ typedef struct ao_macosx_s
   unsigned int buffer_len; ///< must always be num_chunks * chunk_size
   unsigned int num_chunks;
   unsigned int chunk_size;
-} ao_macosx_t;
+} ao_coreaudio_t;
 
-static ao_macosx_t *ao = NULL;
+static ao_coreaudio_t *ao = NULL;
 
 /**
  * \brief add data to ringbuffer
@@ -248,7 +248,7 @@ int b_alive;
 
     ao_msg(MSGT_AO,MSGL_V, "init([%dHz][%dch][%s][%d])\n", rate, channels, af_fmt2str_short(format), flags);
 
-    ao = calloc(1, sizeof(ao_macosx_t));
+    ao = calloc(1, sizeof(ao_coreaudio_t));
 
     ao->i_selected_dev = 0;
     ao->b_supports_digital = 0;
@@ -1,5 +1,5 @@
 /*
- * Mac OS X audio output driver
+ * CoreAudio audio output driver for Mac OS X
  *
  * original copyright (C) Timothy J. Wood - Aug 2000

Modified: trunk/libao2/audio_out.c
==============================================================================